@@ -62,8 +62,8 @@ class DwdMosmixValues(ScalarValuesCore):
     parameter: List
         - If None, data for all parameters is returned.
         - If not None, list of parameters, per MOSMIX definition, see
-          https://www.dwd.de/DE/leistungen/opendata/help/schluessel_datenformate/kml/mosmix_elemente_pdf.pdf?__blob=publicationFile&v=2  # noqa:B950
-    """
+          https://www.dwd.de/DE/leistungen/opendata/help/schluessel_datenformate/kml/mosmix_elemente_pdf.pdf?__blob=publicationFile&v=2
+    """  # noqa:B950,E501
 
     _tz = Timezone.GERMANY
     _data_tz = Timezone.UTC
@@ -125,6 +125,8 @@ class DwdMosmixValues(ScalarValuesCore):
 
         :return:
         """
+        hpm = self._create_humanized_parameters_mapping()
+
         for df in self._collect_station_parameter():
             df = self._coerce_parameter_types(df)
 
@@ -137,7 +139,7 @@ class DwdMosmixValues(ScalarValuesCore):
             df = self._coerce_meta_fields(df)
 
             if self.sr.humanize:
-                df = self._humanize(df)
+                df = self._humanize(df, hpm)
 
             yield ValuesResult(stations=self.sr, df=df)
 
